@@ -1,7 +1,7 @@
 from ejtraderIQ import IQOption
 
 
-api = IQOption('tribolinux@gmail.com','tribopass@123','DEMO')
+api = IQOption('email','password','DEMO')
 
 
 for _ in range(5):
